@@ -3,15 +3,13 @@ from __future__ import annotations
 
 import asyncio
 from collections.abc import Callable
-from dataclasses import dataclass
-import datetime as dt
 import logging
 from typing import Any, cast
 
 import jinja2
 import voluptuous as vol
 
-from homeassistant import config_entries
+from homeassistant import config as conf_util, config_entries
 from homeassistant.components import websocket_api
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
@@ -20,11 +18,9 @@ from homeassistant.const import (
     CONF_PAYLOAD,
     CONF_PORT,
     CONF_USERNAME,
-    EVENT_HOMEASSISTANT_STOP,
     SERVICE_RELOAD,
 )
-from homeassistant.core import Event, HassJob, HomeAssistant, ServiceCall, callback
-from homeassistant.data_entry_flow import BaseServiceInfo
+from homeassistant.core import HassJob, HomeAssistant, ServiceCall, callback
 from homeassistant.exceptions import TemplateError, Unauthorized
 from homeassistant.helpers import config_validation as cv, event, template
 from homeassistant.helpers.device_registry import DeviceEntry
@@ -65,9 +61,10 @@ from .const import (  # noqa: F401
     CONF_TOPIC,
     CONF_WILL_MESSAGE,
     CONFIG_ENTRY_IS_SETUP,
-    DATA_CONFIG_ENTRY_LOCK,
     DATA_MQTT,
     DATA_MQTT_CONFIG,
+    DATA_MQTT_RELOAD_DISPATCHERS,
+    DATA_MQTT_RELOAD_ENTRY,
     DATA_MQTT_RELOAD_NEEDED,
     DATA_MQTT_UPDATED_CONFIG,
     DEFAULT_ENCODING,
@@ -87,7 +84,12 @@ from .models import (  # noqa: F401
     ReceiveMessage,
     ReceivePayloadType,
 )
-from .util import _VALID_QOS_SCHEMA, valid_publish_topic, valid_subscribe_topic
+from .util import (
+    _VALID_QOS_SCHEMA,
+    mqtt_config_entry_enabled,
+    valid_publish_topic,
+    valid_subscribe_topic,
+)
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -105,6 +107,16 @@ CONNECTION_SUCCESS = "connection_success"
 CONNECTION_FAILED = "connection_failed"
 CONNECTION_FAILED_RECOVERABLE = "connection_failed_recoverable"
 
+CONFIG_ENTRY_CONFIG_KEYS = [
+    CONF_BIRTH_MESSAGE,
+    CONF_BROKER,
+    CONF_DISCOVERY,
+    CONF_PASSWORD,
+    CONF_PORT,
+    CONF_USERNAME,
+    CONF_WILL_MESSAGE,
+]
+
 CONFIG_SCHEMA = vol.Schema(
     {
         DOMAIN: vol.All(
@@ -140,18 +152,6 @@ MQTT_PUBLISH_SCHEMA = vol.All(
 )
 
 
-@dataclass
-class MqttServiceInfo(BaseServiceInfo):
-    """Prepared info from mqtt entries."""
-
-    topic: str
-    payload: ReceivePayloadType
-    qos: int
-    retain: bool
-    subscribed_topic: str
-    timestamp: dt.datetime
-
-
 async def _async_setup_discovery(
     hass: HomeAssistant, conf: ConfigType, config_entry
 ) -> None:
@@ -174,7 +174,7 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
         conf = dict(conf)
         hass.data[DATA_MQTT_CONFIG] = conf
 
-    if not bool(hass.config_entries.async_entries(DOMAIN)):
+    if (mqtt_entry_status := mqtt_config_entry_enabled(hass)) is None:
         # Create an import flow if the user has yaml configured entities etc.
         # but no broker configuration. Note: The intention is not for this to
         # import broker configuration from YAML because that has been deprecated.
@@ -185,9 +185,33 @@ async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
                 data={},
             )
         )
+        hass.data[DATA_MQTT_RELOAD_NEEDED] = True
+    elif mqtt_entry_status is False:
+        _LOGGER.info(
+            "MQTT will be not available until the config entry is enabled",
+        )
+        hass.data[DATA_MQTT_RELOAD_NEEDED] = True
+
     return True
 
 
+def _filter_entry_config(hass: HomeAssistant, entry: ConfigEntry) -> None:
+    """Remove unknown keys from config entry data.
+
+    Extra keys may have been added when importing MQTT yaml configuration.
+    """
+    filtered_data = {
+        k: entry.data[k] for k in CONFIG_ENTRY_CONFIG_KEYS if k in entry.data
+    }
+    if entry.data.keys() != filtered_data.keys():
+        _LOGGER.warning(
+            "The following unsupported configuration options were removed from the "
+            "MQTT config entry: %s. Add them to configuration.yaml if they are needed",
+            entry.data.keys() - filtered_data.keys(),
+        )
+        hass.config_entries.async_update_entry(entry, data=filtered_data)
+
+
 def _merge_basic_config(
     hass: HomeAssistant, entry: ConfigEntry, yaml_config: dict[str, Any]
 ) -> None:
@@ -239,17 +263,22 @@ async def _async_config_entry_updated(hass: HomeAssistant, entry: ConfigEntry) -
         await _async_setup_discovery(hass, mqtt_client.conf, entry)
 
 
-async def async_setup_entry(  # noqa: C901
-    hass: HomeAssistant, entry: ConfigEntry
-) -> bool:
-    """Load a config entry."""
+async def async_fetch_config(hass: HomeAssistant, entry: ConfigEntry) -> dict | None:
+    """Fetch fresh MQTT yaml config from the hass config when (re)loading the entry."""
+    if DATA_MQTT_RELOAD_ENTRY in hass.data:
+        hass_config = await conf_util.async_hass_config_yaml(hass)
+        mqtt_config = CONFIG_SCHEMA_BASE(hass_config.get(DOMAIN, {}))
+        hass.data[DATA_MQTT_CONFIG] = mqtt_config
+
+    # Remove unknown keys from config entry data
+    _filter_entry_config(hass, entry)
+
     # Merge basic configuration, and add missing defaults for basic options
     _merge_basic_config(hass, entry, hass.data.get(DATA_MQTT_CONFIG, {}))
-
     # Bail out if broker setting is missing
     if CONF_BROKER not in entry.data:
         _LOGGER.error("MQTT broker is not configured, please configure it")
-        return False
+        return None
 
     # If user doesn't have configuration.yaml config, generate default values
     # for options not in config entry data
@@ -271,22 +300,21 @@ async def async_setup_entry(  # noqa: C901
 
     # Merge advanced configuration values from configuration.yaml
     conf = _merge_extended_config(entry, conf)
+    return conf
 
-    hass.data[DATA_MQTT] = MQTT(
-        hass,
-        entry,
-        conf,
-    )
+
+async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
+    """Load a config entry."""
+    # Merge basic configuration, and add missing defaults for basic options
+    if (conf := await async_fetch_config(hass, entry)) is None:
+        # Bail out
+        return False
+
+    hass.data[DATA_MQTT] = MQTT(hass, entry, conf)
     entry.add_update_listener(_async_config_entry_updated)
 
     await hass.data[DATA_MQTT].async_connect()
 
-    async def async_stop_mqtt(_event: Event):
-        """Stop MQTT component."""
-        await hass.data[DATA_MQTT].async_disconnect()
-
-    hass.bus.async_listen_once(EVENT_HOMEASSISTANT_STOP, async_stop_mqtt)
-
     async def async_publish_service(call: ServiceCall) -> None:
         """Handle MQTT publish service calls."""
         msg_topic = call.data.get(ATTR_TOPIC)
@@ -375,7 +403,6 @@ async def async_setup_entry(  # noqa: C901
     )
 
     # setup platforms and discovery
-    hass.data[DATA_CONFIG_ENTRY_LOCK] = asyncio.Lock()
     hass.data[CONFIG_ENTRY_IS_SETUP] = set()
 
     async def async_setup_reload_service() -> None:
@@ -411,6 +438,7 @@ async def async_setup_entry(  # noqa: C901
         # pylint: disable-next=import-outside-toplevel
         from . import device_automation, tag
 
+        # Forward the entry setup to the MQTT platforms
         await asyncio.gather(
             *(
                 [
@@ -428,21 +456,25 @@ async def async_setup_entry(  # noqa: C901
             await _async_setup_discovery(hass, conf, entry)
         # Setup reload service after all platforms have loaded
         await async_setup_reload_service()
-
         if DATA_MQTT_RELOAD_NEEDED in hass.data:
             hass.data.pop(DATA_MQTT_RELOAD_NEEDED)
-            await hass.services.async_call(
-                DOMAIN,
-                SERVICE_RELOAD,
-                {},
-                blocking=False,
-            )
+            await async_reload_manual_mqtt_items(hass)
 
-    hass.async_create_task(async_forward_entry_setup_and_setup_discovery(entry))
+    await async_forward_entry_setup_and_setup_discovery(entry)
 
     return True
 
 
+async def async_reload_manual_mqtt_items(hass: HomeAssistant) -> None:
+    """Reload manual configured MQTT items."""
+    await hass.services.async_call(
+        DOMAIN,
+        SERVICE_RELOAD,
+        {},
+        blocking=True,
+    )
+
+
 @websocket_api.websocket_command(
     {vol.Required("type"): "mqtt/device/debug_info", vol.Required("device_id"): str}
 )
@@ -544,3 +576,49 @@ async def async_remove_config_entry_device(
 
     await device_automation.async_removed_from_device(hass, device_entry.id)
     return True
+
+
+async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
+    """Unload MQTT dump and publish service when the config entry is unloaded."""
+    # Unload publish and dump services.
+    hass.services.async_remove(
+        DOMAIN,
+        SERVICE_PUBLISH,
+    )
+    hass.services.async_remove(
+        DOMAIN,
+        SERVICE_DUMP,
+    )
+
+    # Stop the discovery
+    await discovery.async_stop(hass)
+    mqtt_client: MQTT = hass.data[DATA_MQTT]
+    # Unload the platforms
+    await asyncio.gather(
+        *(
+            hass.config_entries.async_forward_entry_unload(entry, component)
+            for component in PLATFORMS
+        )
+    )
+    await hass.async_block_till_done()
+    # Unsubscribe reload dispatchers
+    while reload_dispatchers := hass.data.setdefault(DATA_MQTT_RELOAD_DISPATCHERS, []):
+        reload_dispatchers.pop()()
+    hass.data[CONFIG_ENTRY_IS_SETUP] = set()
+    # Cleanup listeners
+    mqtt_client.cleanup()
+
+    # Trigger reload manual MQTT items at entry setup
+    # Reload the legacy yaml platform
+    await async_reload_integration_platforms(hass, DOMAIN, RELOADABLE_PLATFORMS)
+    if (mqtt_entry_status := mqtt_config_entry_enabled(hass)) is False:
+        # The entry is disabled reload legacy manual items when the entry is enabled again
+        hass.data[DATA_MQTT_RELOAD_NEEDED] = True
+    elif mqtt_entry_status is True:
+        # The entry is reloaded:
+        # Trigger re-fetching the yaml config at entry setup
+        hass.data[DATA_MQTT_RELOAD_ENTRY] = True
+    # Stop the loop
+    await mqtt_client.async_disconnect()
+
+    return True
