@@ -100,10 +100,17 @@ async def async_setup_entry(
 
 
 async def _async_setup_entity(
-    hass, async_add_entities, config, config_entry=None, discovery_data=None
-):
+    hass: HomeAssistant,
+    async_add_entities: AddEntitiesCallback,
+    config: ConfigType,
+    config_entry: ConfigEntry | None = None,
+    discovery_data: dict | None = None,
+) -> None:
     """Set up the MQTT vacuum."""
-    setup_entity = {LEGACY: async_setup_entity_legacy, STATE: async_setup_entity_state}
+    setup_entity = {
+        LEGACY: async_setup_entity_legacy,
+        STATE: async_setup_entity_state,
+    }
     await setup_entity[config[CONF_SCHEMA]](
         hass, config, async_add_entities, config_entry, discovery_data
     )
