@@ -61,6 +61,8 @@ async def async_setup_sdm_entry(
 class NestCamera(Camera):
     """Devices that support cameras."""
 
+    _attr_has_entity_name = True
+
     def __init__(self, device: Device) -> None:
         """Initialize the camera."""
         super().__init__()
@@ -83,11 +85,6 @@ class NestCamera(Camera):
         # The API "name" field is a unique device identifier.
         return f"{self._device.name}-camera"
 
-    @property
-    def name(self) -> str | None:
-        """Return the name of the camera."""
-        return self._device_info.device_name
-
     @property
     def device_info(self) -> DeviceInfo:
         """Return device specific attributes."""
