@@ -4,7 +4,7 @@ from __future__ import annotations
 from collections.abc import Callable
 import dataclasses
 from functools import partial, wraps
-from typing import Any, Literal
+from typing import Any, Literal, cast
 
 from aiohttp import web, web_exceptions, web_request
 import voluptuous as vol
@@ -54,7 +54,6 @@ from homeassistant.components.websocket_api.const import (
     ERR_UNKNOWN_ERROR,
 )
 from homeassistant.config_entries import ConfigEntry, ConfigEntryState
-from homeassistant.const import CONF_URL
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.exceptions import Unauthorized
 from homeassistant.helpers import config_validation as cv
@@ -72,6 +71,7 @@ from .const import (
 from .helpers import (
     async_enable_statistics,
     async_get_node_from_device_id,
+    get_device_id,
     update_data_collection_preference,
 )
 
@@ -378,6 +378,7 @@ def node_status(node: Node) -> dict[str, Any]:
 def async_register_api(hass: HomeAssistant) -> None:
     """Register all of our api endpoints."""
     websocket_api.async_register_command(hass, websocket_network_status)
+    websocket_api.async_register_command(hass, websocket_subscribe_node_status)
     websocket_api.async_register_command(hass, websocket_node_status)
     websocket_api.async_register_command(hass, websocket_node_metadata)
     websocket_api.async_register_command(hass, websocket_node_comments)
@@ -413,16 +414,22 @@ def async_register_api(hass: HomeAssistant) -> None:
     )
     websocket_api.async_register_command(hass, websocket_data_collection_status)
     websocket_api.async_register_command(hass, websocket_abort_firmware_update)
+    websocket_api.async_register_command(hass, websocket_get_firmware_update_progress)
     websocket_api.async_register_command(
         hass, websocket_subscribe_firmware_update_status
     )
+    websocket_api.async_register_command(
+        hass, websocket_get_firmware_update_capabilities
+    )
+    websocket_api.async_register_command(
+        hass, websocket_get_any_firmware_update_progress
+    )
     websocket_api.async_register_command(hass, websocket_check_for_config_updates)
     websocket_api.async_register_command(hass, websocket_install_config_update)
     websocket_api.async_register_command(
         hass, websocket_subscribe_controller_statistics
     )
     websocket_api.async_register_command(hass, websocket_subscribe_node_statistics)
-    websocket_api.async_register_command(hass, websocket_node_ready)
     hass.http.register_view(FirmwareUploadView())
 
 
@@ -497,25 +504,28 @@ async def websocket_network_status(
 
 @websocket_api.websocket_command(
     {
-        vol.Required(TYPE): "zwave_js/node_ready",
+        vol.Required(TYPE): "zwave_js/subscribe_node_status",
         vol.Required(DEVICE_ID): str,
     }
 )
 @websocket_api.async_response
 @async_get_node
-async def websocket_node_ready(
+async def websocket_subscribe_node_status(
     hass: HomeAssistant,
     connection: ActiveConnection,
     msg: dict,
     node: Node,
 ) -> None:
-    """Subscribe to the node ready event of a Z-Wave JS node."""
+    """Subscribe to node status update events of a Z-Wave JS node."""
 
     @callback
     def forward_event(event: dict) -> None:
         """Forward the event."""
         connection.send_message(
-            websocket_api.event_message(msg[ID], {"event": event["event"]})
+            websocket_api.event_message(
+                msg[ID],
+                {"event": event["event"], "status": node.status, "ready": node.ready},
+            )
         )
 
     @callback
@@ -525,7 +535,10 @@ async def websocket_node_ready(
             unsub()
 
     connection.subscriptions[msg["id"]] = async_cleanup
-    msg[DATA_UNSUBSCRIBE] = unsubs = [node.on("ready", forward_event)]
+    msg[DATA_UNSUBSCRIBE] = unsubs = [
+        node.on(evt, forward_event)
+        for evt in ("alive", "dead", "sleep", "wake up", "ready")
+    ]
 
     connection.send_result(msg[ID])
 
@@ -1102,8 +1115,7 @@ async def websocket_remove_node(
 @websocket_api.websocket_command(
     {
         vol.Required(TYPE): "zwave_js/replace_failed_node",
-        vol.Required(ENTRY_ID): str,
-        vol.Required(NODE_ID): int,
+        vol.Required(DEVICE_ID): str,
         vol.Optional(INCLUSION_STRATEGY, default=InclusionStrategy.DEFAULT): vol.All(
             vol.Coerce(int),
             vol.In(
@@ -1126,18 +1138,16 @@ async def websocket_remove_node(
 )
 @websocket_api.async_response
 @async_handle_failed_command
-@async_get_entry
+@async_get_node
 async def websocket_replace_failed_node(
     hass: HomeAssistant,
     connection: ActiveConnection,
     msg: dict,
-    entry: ConfigEntry,
-    client: Client,
-    driver: Driver,
+    node: Node,
 ) -> None:
     """Replace a failed node with a new node."""
-    controller = driver.controller
-    node_id = msg[NODE_ID]
+    assert node.client.driver
+    controller = node.client.driver.controller
     inclusion_strategy = InclusionStrategy(msg[INCLUSION_STRATEGY])
     force_security = msg.get(FORCE_SECURITY)
     provisioning = (
@@ -1251,7 +1261,7 @@ async def websocket_replace_failed_node(
 
     try:
         result = await controller.async_replace_failed_node(
-            controller.nodes[node_id],
+            node,
             INCLUSION_STRATEGY_NOT_SMART_START[inclusion_strategy.value],
             force_security=force_security,
             provisioning=provisioning,
@@ -1486,8 +1496,8 @@ async def websocket_refresh_node_info(
         node.on("interview failed", forward_event),
     ]
 
-    result = await node.async_refresh_info()
-    connection.send_result(msg[ID], result)
+    await node.async_refresh_info()
+    connection.send_result(msg[ID])
 
 
 @websocket_api.require_admin
@@ -1861,6 +1871,26 @@ async def websocket_abort_firmware_update(
     connection.send_result(msg[ID])
 
 
+@websocket_api.require_admin
+@websocket_api.websocket_command(
+    {
+        vol.Required(TYPE): "zwave_js/get_firmware_update_progress",
+        vol.Required(DEVICE_ID): str,
+    }
+)
+@websocket_api.async_response
+@async_handle_failed_command
+@async_get_node
+async def websocket_get_firmware_update_progress(
+    hass: HomeAssistant,
+    connection: ActiveConnection,
+    msg: dict,
+    node: Node,
+) -> None:
+    """Get whether firmware update is in progress."""
+    connection.send_result(msg[ID], await node.async_get_firmware_update_progress())
+
+
 def _get_firmware_update_progress_dict(
     progress: FirmwareUpdateProgress,
 ) -> dict[str, int]:
@@ -1941,6 +1971,51 @@ async def websocket_subscribe_firmware_update_status(
         )
 
 
+@websocket_api.require_admin
+@websocket_api.websocket_command(
+    {
+        vol.Required(TYPE): "zwave_js/get_firmware_update_capabilities",
+        vol.Required(DEVICE_ID): str,
+    }
+)
+@websocket_api.async_response
+@async_handle_failed_command
+@async_get_node
+async def websocket_get_firmware_update_capabilities(
+    hass: HomeAssistant,
+    connection: ActiveConnection,
+    msg: dict,
+    node: Node,
+) -> None:
+    """Abort a firmware update."""
+    capabilities = await node.async_get_firmware_update_capabilities()
+    connection.send_result(msg[ID], capabilities.to_dict())
+
+
+@websocket_api.require_admin
+@websocket_api.websocket_command(
+    {
+        vol.Required(TYPE): "zwave_js/get_any_firmware_update_progress",
+        vol.Required(ENTRY_ID): str,
+    }
+)
+@websocket_api.async_response
+@async_handle_failed_command
+@async_get_entry
+async def websocket_get_any_firmware_update_progress(
+    hass: HomeAssistant,
+    connection: ActiveConnection,
+    msg: dict,
+    entry: ConfigEntry,
+    client: Client,
+    driver: Driver,
+) -> None:
+    """Get whether any firmware updates are in progress."""
+    connection.send_result(
+        msg[ID], await driver.controller.async_get_any_firmware_update_progress()
+    )
+
+
 class FirmwareUploadView(HomeAssistantView):
     """View to upload firmware."""
 
@@ -1965,16 +2040,6 @@ class FirmwareUploadView(HomeAssistantView):
                 raise web_exceptions.HTTPBadRequest
             raise web_exceptions.HTTPNotFound
 
-        if not self._dev_reg:
-            self._dev_reg = dr.async_get(hass)
-        device = self._dev_reg.async_get(device_id)
-        assert device
-        entry = next(
-            entry
-            for entry in hass.config_entries.async_entries(DOMAIN)
-            if entry.entry_id in device.config_entries
-        )
-
         # Increase max payload
         request._client_max_size = 1024 * 1024 * 10  # pylint: disable=protected-access
 
@@ -1983,18 +2048,23 @@ class FirmwareUploadView(HomeAssistantView):
         if "file" not in data or not isinstance(data["file"], web_request.FileField):
             raise web_exceptions.HTTPBadRequest
 
+        target = None
+        if "target" in data:
+            target = int(cast(str, data["target"]))
+
         uploaded_file: web_request.FileField = data["file"]
 
         try:
             await begin_firmware_update(
-                entry.data[CONF_URL],
+                node.client.ws_server_url,
                 node,
                 uploaded_file.filename,
                 await hass.async_add_executor_job(uploaded_file.file.read),
                 async_get_clientsession(hass),
+                target=target,
             )
         except BaseZwaveJSServerError as err:
-            raise web_exceptions.HTTPBadRequest from err
+            raise web_exceptions.HTTPBadRequest(reason=str(err)) from err
 
         return self.json(None)
 
@@ -2127,15 +2197,42 @@ async def websocket_subscribe_controller_statistics(
     )
 
 
-def _get_node_statistics_dict(statistics: NodeStatistics) -> dict[str, int]:
+def _get_node_statistics_dict(
+    hass: HomeAssistant, statistics: NodeStatistics
+) -> dict[str, Any]:
     """Get dictionary of node statistics."""
-    return {
+    dev_reg = dr.async_get(hass)
+
+    def _convert_node_to_device_id(node: Node) -> str:
+        """Convert a node to a device id."""
+        driver = node.client.driver
+        assert driver
+        device = dev_reg.async_get_device({get_device_id(driver, node)})
+        assert device
+        return device.id
+
+    data: dict = {
         "commands_tx": statistics.commands_tx,
         "commands_rx": statistics.commands_rx,
         "commands_dropped_tx": statistics.commands_dropped_tx,
         "commands_dropped_rx": statistics.commands_dropped_rx,
         "timeout_response": statistics.timeout_response,
+        "rtt": statistics.rtt,
+        "rssi": statistics.rssi,
+        "lwr": statistics.lwr.as_dict() if statistics.lwr else None,
+        "nlwr": statistics.nlwr.as_dict() if statistics.nlwr else None,
     }
+    for key in ("lwr", "nlwr"):
+        if not data[key]:
+            continue
+        for key_2 in ("repeaters", "route_failed_between"):
+            if not data[key][key_2]:
+                continue
+            data[key][key_2] = [
+                _convert_node_to_device_id(node) for node in data[key][key_2]
+            ]
+
+    return data
 
 
 @websocket_api.require_admin
@@ -2171,7 +2268,7 @@ async def websocket_subscribe_node_statistics(
                     "event": event["event"],
                     "source": "node",
                     "node_id": node.node_id,
-                    **_get_node_statistics_dict(statistics),
+                    **_get_node_statistics_dict(hass, statistics),
                 },
             )
         )
@@ -2187,7 +2284,7 @@ async def websocket_subscribe_node_statistics(
                 "event": "statistics updated",
                 "source": "node",
                 "nodeId": node.node_id,
-                **_get_node_statistics_dict(node.statistics),
+                **_get_node_statistics_dict(hass, node.statistics),
             },
         )
     )
